#include "mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    i_label("Start", this)
{

    mVBox = NULL;
    //  Guard against a possible mis-timing with the
    //  MenuBar constructor.

    sw_pixmap = new QPixmap(":/res/images/Unknown.jpg");
    //  Apparently, the allocator 'new' is executed asynchronously,
    //  which allows main() to execute MainWindow::resize() before
    //  the code below is allowed to run...

    int width = size().width();
    int height = size().height();
    i_label.setPixmap(sw_pixmap->scaled(width - 20, height - 50, Qt::KeepAspectRatio, Qt::SmoothTransformation));
    central_widget = new QWidget;
    mVBox = new QVBoxLayout(central_widget);

    mVBox -> addWidget(&i_label, 0, Qt::AlignCenter);
    //  MenuBar will be added later...

    setCentralWidget(central_widget);
}

void MainWindow::resizeEvent(QResizeEvent* event)
{
   QMainWindow::resizeEvent(event);
   int width = size().width();
   int height = size().height();
   i_label.setPixmap(sw_pixmap->scaled(width - 20, height - 50, Qt::KeepAspectRatio, Qt::SmoothTransformation));
}

//  Apparently, attempts to delete
//  'VBox', 'central_widget', or 'sw_pixmap'
//  all cause crashes on exiting,
//  because the Widgets are still being displayed,
//  though deleted. Therefore, the non-default
//  destructor deletes nothing...
MainWindow::~MainWindow() { }


//  Below are the custom implementations of some Slots...
//  Memory leaks that would result from the user
//  switching the pixmap often are avoided,
//  by deleting the pixmap before doing so each time.

//  Apparently, this causes no crashes as of Qt 5.7 ...
//  A possible reason why no crahes result may be,
//  the fact that the text "Start" has been set, and is
//  an alternative to display in the absence of any
//  pixmap.

void MainWindow::resetQ()
{
    delete sw_pixmap;
    sw_pixmap = NULL;
    sw_pixmap = new QPixmap(":/res/images/Unknown.jpg");
    int width = size().width();
    int height = size().height();
    i_label.setPixmap(sw_pixmap->scaled(width - 20, height - 50, Qt::KeepAspectRatio, Qt::SmoothTransformation));
}

void MainWindow::setLOT()
{
    delete sw_pixmap;
    sw_pixmap = NULL;
    sw_pixmap = new QPixmap(":/res/images/Gudula.jpg");
    int width = size().width();
    int height = size().height();
    i_label.setPixmap(sw_pixmap->scaled(width - 20, height - 50, Qt::KeepAspectRatio, Qt::SmoothTransformation));
}

void MainWindow::setROT()
{
    delete sw_pixmap;
    sw_pixmap = NULL;
    sw_pixmap = new QPixmap(":/res/images/Maria_Dad_me.jpg");
    int width = size().width();
    int height = size().height();
    i_label.setPixmap(sw_pixmap->scaled(width - 20, height - 50, Qt::KeepAspectRatio, Qt::SmoothTransformation));
}
